@@ -7,6 +7,7 @@ Unit tests for coarse channel metadata
 */
 #[cfg(test)]
 use super::*;
+use float_cmp::*;
 use std::collections::BTreeMap;
 
 // Create a BTree Structure for testing
@@ -600,3 +601,319 @@ fn test_get_coarse_chan_indicies() {
     assert_eq!(indices_3.len(), 1);
     assert_eq!(indices_3[0], 1);
 }
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_legacy_40khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    assert_eq!(metafits_chan_array.len(), 24);
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrLegacy;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 40_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_055_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_legacy_20khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrLegacy;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 20_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_045_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_hz_legacy_10khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrLegacy;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 10_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_040_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_mwaxv2_40khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrMWAXv2;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 40_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_040_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_mwaxv2_20khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrMWAXv2;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 20_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_040_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_mwaxv2_10khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrMWAXv2;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 10_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_040_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
+
+#[test]
+fn test_get_fine_chan_centres_array_hz_mwaxv2_2khz() {
+    let metafits_chan_array: Vec<_> = (131..155).collect();
+    let channel_width = 1_280_000;
+    let mwa_version: MWAVersion = MWAVersion::CorrMWAXv2;
+
+    // Process coarse channels
+    let coarse_chan_array = CoarseChannel::populate_coarse_channels(
+        mwa_version,
+        &metafits_chan_array,
+        channel_width,
+        None,
+        None,
+    )
+    .unwrap();
+
+    let fine_chan_width_hz: u32 = 256_000;
+    let num_fine_chans_per_coarse: usize = channel_width as usize / fine_chan_width_hz as usize;
+
+    let calc_fine_chan_centre_array_hz = CoarseChannel::get_fine_chan_centres_array_hz(
+        mwa_version,
+        &coarse_chan_array,
+        fine_chan_width_hz,
+        num_fine_chans_per_coarse,
+    );
+
+    // Check we have the right number of fine channels
+    assert_eq!(
+        calc_fine_chan_centre_array_hz.len(),
+        24 * num_fine_chans_per_coarse
+    );
+
+    // Check values
+    assert!(
+        approx_eq!(
+            f64,
+            167_168_000.0,
+            calc_fine_chan_centre_array_hz[0],
+            F64Margin::default()
+        ),
+        "calculated value: {}",
+        calc_fine_chan_centre_array_hz[0]
+    );
+}
